Struct pancake_engine_ssi::lsm::unit::commit_info::CommitVer
source · pub struct CommitVer(u64);Expand description
The commit version uniquely identifies every commitment as well as the datastore state after the commitment.
The datastore’s commit version increases for the whole lifetime of the datastore instance.
Tuple Fields
0: u64Implementations